\name{DLBCL}
\alias{DLBCL}
\title{
Diffuse large B-cell lymphoma
}
\description{
A data frame with gene expression data from DLBCL (diffuse large B-cell
lymphoma) patients.
}
\usage{
data(DLBCL)
}
\format{
\describe{
\item{\code{DLCLid}}{DLBCL identifier}
\item{\code{GEG}}{Gene Expression Group}
\item{\code{time}}{survival time in month}
\item{\code{cens}}{censoring: 0 cencored, 1 dead}
\item{\code{IPI}}{International Prognostic Index}
\item{\code{MGE}}{Mean Gene Expression}
}
}
\source{

Except of \code{MGE}, the data is published at
\url{http://llmpp.nih.gov/lymphoma/data.shtml}. \code{MGE} is the mean of
the gene expression.

}
\references{

Ash A. Alizadeh et. al (2000), Distinct types of diffuse large
B-cell lymphoma identified by gene
expression profiling. \emph{Nature}, \bold{403}, 504--509

}

\examples{

data(DLBCL)

# compute the cutpoint and plot the empirical process 

mod <- maxstat.test(Surv(time, cens) ~ MGE, data=DLBCL, smethod="LogRank")

print(mod)

\dontrun{
  # postscript("statDLBCL.ps", horizontal=F, width=8, height=8)
  pdf("statDLBCL.pdf", width=8, height=8)
}
par(mai=c(1.0196235, 1.0196235, 0.8196973, 0.4198450))
plot(mod, cex.lab=1.6, cex.axis=1.6, xlab="Mean gene expression",lwd=2)
\dontrun{
  dev.off()
}

# significance of the cutpoint
# limiting distribution

maxstat.test(Surv(time, cens) ~ MGE, data=DLBCL,
             smethod="LogRank", pmethod="Lau92", iscores=TRUE)

# improved Bonferroni inequality, plot with significance bound

maxstat.test(Surv(time, cens) ~ MGE, data=DLBCL,
             smethod="LogRank", pmethod="Lau94", iscores=TRUE)

mod <- maxstat.test(Surv(time, cens) ~ MGE, data=DLBCL, smethod="LogRank",
                    pmethod="Lau94", alpha=0.05)
plot(mod, xlab="Mean gene expression")

\dontrun{
#  postscript(file="RNewsStat.ps",horizontal=F, width=8, height=8)
   pdf("RNewsStat.pdf", width=8, height=8)

}
par(mai=c(1.0196235, 1.0196235, 0.8196973, 0.4198450))
plot(mod, xlab="Mean gene expression", cex.lab=1.6, cex.axis=1.6)
\dontrun{
  dev.off()
}

# small sample solution Hothorn & Lausen

maxstat.test(Surv(time, cens) ~ MGE, data=DLBCL,
             smethod="LogRank", pmethod="HL")

# normal approximation

maxstat.test(Surv(time, cens) ~ MGE, data=DLBCL,
             smethod="LogRank", pmethod="exactGauss", iscores=TRUE,
             abseps=0.01)

# conditional Monte-Carlo

maxstat.test(Surv(time, cens) ~ MGE, data=DLBCL,
             smethod="LogRank", pmethod="condMC", B = 9999) 

# survival analysis and plotting like in Alizadeh et al. (2000)

if(require(survival, quietly = TRUE)) {

  splitGEG <- rep(1, nrow(DLBCL))
  DLBCL <- cbind(DLBCL, splitGEG)
  DLBCL$splitGEG[DLBCL$GEG == "Activated B-like"] <- 0

  plot(survfit(Surv(time, cens) ~ splitGEG, data=DLBCL),
       xlab="Survival time in month", ylab="Probability")

  text(90, 0.7, "GC B-like")
  text(60, 0.3, "Activated B-like")

  splitIPI <- rep(1, nrow(DLBCL))
  DLBCL <- cbind(DLBCL, splitIPI)
  DLBCL$splitIPI[DLBCL$IPI <= 2] <- 0

  plot(survfit(Surv(time, cens) ~ splitIPI, data=DLBCL),
       xlab="Survival time in month", ylab="Probability")

  text(90, 0.7, "Low clinical risk")
  text(60, 0.25, "High clinical risk")

  # survival analysis using the cutpoint 

  splitMGE <- rep(1, nrow(DLBCL))
  DLBCL <- cbind(DLBCL, splitMGE)
  DLBCL$splitMGE[DLBCL$MGE <= mod$estimate] <- 0

  \dontrun{
   # postscript("survDLBCL.ps",horizontal=F, width=8, height=8)
    pdf("survDLBCL.pdf", width=8, height=8)

  }
  par(mai=c(1.0196235, 1.0196235, 0.8196973, 0.4198450))

  plot(survfit(Surv(time, cens) ~ splitMGE, data=DLBCL),
       xlab = "Survival time in month",
       ylab="Probability", cex.lab=1.6, cex.axis=1.6, lwd=2)

  text(90, 0.9, expression("Mean gene expression" > 0.186), cex=1.6)   
  text(90, 0.45, expression("Mean gene expression" <= 0.186 ), cex=1.6)   

  \dontrun{
    dev.off()
  }
}

}
\keyword{datasets}

\eof
\name{LausenTab2}
\alias{LausenTab2}
\title{
Table 2 of Lausen and Schumacher (1992)
}
\description{
Table 2 of Lausen and Schumacher (1992)
}
\usage{
data(LausenTab2)
}
\references{
Lausen, B. and Schumacher, M. (1992), Maximally Selected Rank Statistics.
\emph{Biometrics} \bold{48}, 73--85
}
\keyword{datasets}

\eof
\name{corrmsrs}
\alias{corrmsrs}
\title{ Correlation Matrix }
\description{
 Correlation matrix of maximally selected rank statistics. 
}
\usage{
corrmsrs(X, minprop=0.1, maxprop=0.9)
}
\arguments{
  \item{X}{the vector, matrix or data.frame of prognostic factors under
test.}
  \item{minprop}{ at least \code{minprop}*100\% of the observations in the
                  first group. }
  \item{maxprop}{ not more than \code{minprop}*100\% of the observations in
                  the first group. }

}
\details{
  The correlations between all two-sample rank statistics induced by all
possible cutpoints in \code{X} are computed. 

}
\value{
The correlation matrix with dimension depending on ties in \code{X} is
returned.
}
\references{

        Hothorn, T. and Lausen, B. (2003).
        On the Exact Distribution of Maximally Selected Rank Statistics. 
        \emph{Computational Statistics \& Data Analysis}, \bold{43}, 
        121--137.

        Lausen, B., Hothorn, T., Bretz, F. and Schmacher, M. (2002).
        Assessment of Optimally Selected Prognostic Factors.
	\emph{submitted}. Preprint available from
	\url{http://www.mathpreprints.com/math/Preprint/blausen/20021007/1/}
}
 
\author{ Torsten Hothorn <Torsten.Hothorn@rzmail.uni-erlangen.de> }
\examples{

# matrix of hypothetical prognostic factors

X <- matrix(rnorm(30), ncol=3) 

# this function

print(system.time(a <- corrmsrs(X, minprop=0, maxprop=0.999)))

# coded by just typing the definition of the correlation

testcorr <- function(X) {
  wh <- function(cut, x)
    which(x <= cut)
  index <- function(x) {
    ux <- unique(x)
    ux <- ux[ux < max(ux)]
    lapply(ux, wh, x = x)
  }
  a <- unlist(test <- apply(X, 2, index), recursive=FALSE)
  cnull <- rep(0, nrow(X))
  mycorr <- diag(length(a))
  for (i in 1:(length(a)-1)) {
    for (j in (i+1):length(a)) {
      cone <- cnull
      cone[a[[i]]] <- 1
      ctwo <- cnull
      ctwo[a[[j]]] <- 1
      sone <- sqrt(sum((cone - mean(cone))^2))
      stwo <- sqrt(sum((ctwo - mean(ctwo))^2))
      tcorr <- sum((cone - mean(cone))*(ctwo - mean(ctwo)))
      tcorr <- tcorr/(sone * stwo)
      mycorr[i,j] <- tcorr
    }
  }
  mycorr
}

print(system.time(tc <- testcorr(X)))
tc <- tc + t(tc)
diag(tc) <- 1
stopifnot(all.equal(tc, a))

}
\keyword{misc}

\eof
\name{hohnloser}
\alias{hohnloser}
\title{
Left ventricular ejection fraction of patients with malignant ventricular
tachyarrhythmias.
}
\description{
A data frame with the left ventricular ejection fraction of patients with
malignant ventricular tachyarrhythmias including recurrence-free month and censoring.
}
\usage{
data(hohnloser)
}
\format{
\describe{
\item{\code{EF}}{left ventricular ejection in percent}
\item{\code{month}}{recurrence-free month}
\item{\code{cens}}{censoring: 0 cencored, 1 not censored}
}
The data used here is published in Table 1 of Lausen and Schumacher (1992).
}
\source{

The data was first published by Hohnloser et al. (1987), 
the data used here is published in Table 1 of Lausen and Schumacher (1992).

}
\references{

Hohnloser, S.H., Raeder, E.A., Podrid, P.J., Graboys, T.B. and Lown, B.
(1987), Predictors of antiarrhythmic drug efficacy in patients with
malignant ventricular tachyarrhythmias. \emph{American Heart Journal}
\bold{114}, 1--7


Lausen, B. and Schumacher, M. (1992), Maximally Selected Rank Statistics.
\emph{Biometrics} \bold{48}, 73--85
}

\examples{

data(hohnloser)

# limiting distribution

maxstat.test(Surv(month, cens) ~ EF, data=hohnloser, 
smethod="LogRank", pmethod="Lau92")

# with integer valued scores for comparison

maxstat.test(Surv(month, cens) ~ EF, data=hohnloser, 
smethod="LogRank", pmethod="Lau92", iscores=TRUE)

# improved Bonferroni inequality

maxstat.test(Surv(month, cens) ~ EF, data=hohnloser,
smethod="LogRank", pmethod="Lau94")

maxstat.test(Surv(month, cens) ~ EF, data=hohnloser,
smethod="LogRank", pmethod="Lau94", iscores=TRUE)


# small sample solution by Hothorn & Lausen

maxstat.test(Surv(month, cens) ~ EF, data=hohnloser,
smethod="LogRank", pmethod="HL")

# normal approximation

maxstat.test(Surv(month, cens) ~ EF, data=hohnloser,
smethod="LogRank", pmethod="exactGauss")

maxstat.test(Surv(month, cens) ~ EF, data=hohnloser,
smethod="LogRank", pmethod="exactGauss", iscores=TRUE)

# conditional Monte-Carlo

maxstat.test(Surv(month, cens) ~ EF, data=hohnloser,
smethod="LogRank", pmethod="condMC", B = 9999)

}

\keyword{datasets}

\eof
\name{maxstat.test}
\alias{maxstat.test}
\alias{maxstat.test.data.frame}
\alias{maxstat.test.default}
\alias{maxstat}
\title{ Maximally Selected Rank and Statistics }
\description{
Performs a test of independence of a response and one or more covariables
using maximally selected rank statistics.
}
\usage{
\method{maxstat.test}{data.frame}(formula, data, subset, na.action, \dots)
maxstat(y, x=NULL, smethod=c("Wilcoxon", "Median",
            "NormalQuantil","LogRank", "Data"), pmethod=c("none", "Lau92",
            "Lau94", "exactGauss", "HL", "condMC", "min"), iscores=(pmethod=="HL"),
            minprop = 0.1, maxprop=0.9, alpha = NULL, keepxy=TRUE, \dots)
}
\arguments{
  \item{y}{ numeric vector of data values, dependent variable. }
  \item{x}{ numeric vector of data values, independent variable. }
  \item{smethod}{ kind of statistic to be computed, i.e. defines the scores
to be used for computing the statistic. }
  \item{pmethod}{ kind of p-value approximation to be used. }
  \item{iscores}{ logical: should the scores be mapped into integers
\code{1:length(x)}? This is TRUE by default for \code{pmethod=="HL"} and
FALSE otherwise.}
  \item{minprop}{ at least \code{minprop}*100\% of the observations in the
                  first group. }
  \item{maxprop}{ not more than \code{minprop}*100\% of the observations in
                  the first group. }
  \item{alpha}{significance niveau, the appropriate quantile is computed if
   \code{alpha} is specified. Used for plotting within \code{\link{plot.maxtest}}.}
  \item{keepxy}{logical: return \code{y} and \code{x} as elements of the
\code{maxtest} object.}
  \item{formula}{ a formula describing the model to be tested of the form
    \code{lhs ~ rhs} where \code{lhs} is the response variable. 
    For survival problems, i.e. using the log-rank statistic, the
    formula is of the form \code{Surv(time, event) ~ rhs}, see above.}
  \item{data}{an data frame containing the variables in the
    model formula. \code{data} is required.}
  \item{subset}{an optional vector specifying a subset of observations
    to be used.}
  \item{na.action}{a function which indicates what should happen when
    the data contain \code{NA}s.  Defaults to
    \code{getOption("na.action")}.}
  \item{\dots}{additional parameters to be passed to
               \code{\link[mvtnorm]{pmvnorm}} or \code{B}, an integer
               defining the number of Monte-Carlo replications.}
}
\details{

The assessment of the predictive power of a variable \code{x} for a
dependent variable \code{y} can be determined by a maximally selected rank
statistic. 

\code{smethod} determines the kind of statistic to be used. 
\code{Wilcoxon} and \code{Median} denote maximally selected 
Wilcoxon and Median statistics. \code{NormalQuantile} and 
\code{LogRank} denote v.d. Waerden and log-rank
scores. 

\code{pmethod} specifies which kind of approximation of the p-value should
be used. \code{Lau92} is the limiting distribution by a Brownian bridge
(see Lausen and Schumacher, 1992, and \code{\link{pLausen92}}), 
\code{Lau94} the approximation based on an improved Bonferroni 
inequality (see Lausen, Sauerbrei and Schumacher, 1994, and \code{\link{pLausen94}}).

\code{exactGauss} returns the exact p-value for a maximally selected Gauss
statistic, see Hothorn and Lausen (2003).

\code{HL} is a small sample approximation based on the Streitberg-R\"ohmel
algorithm (see \code{\link[exactRankTest]{pperm}}) introduced by Hothorn and
Lausen (2003). This requires integer
valued scores. For v. d. Waerden and Log-rank scores we try to find
integer valued scores having the same shape. This results in slightly
different scores (and a different test), the procedure is described in
Hothorn (2001) and Hothorn and Lausen (2003).  

All the approximations are known to be conservative, so \code{min} gives
the minimum p-value of all procedures.

\code{condMC} simulates the distribution via conditional Monte-Carlo. 

For survival problems, i.e. using a maximally selected log-rank statistic,
the interface is similar to \code{\link[survival]{survfit}}. The depended
variable is a survival object \code{Surv(time, event)}. The argument 
\code{event} may be a numeric vector of \code{0} (alive) and \code{1}
(dead) or a vector of logicals with \code{TRUE} indicating death.

If more than one covariable is specified in the right hand side of
\code{formula} (or if \code{x} is a matrix or data frame), the variable with
smallest p-value is selected and the p-value for the global test problem of
independence of \code{y} and every variable on the right hand side is
returned (see Lausen et al., 2002). 

}
\value{
An object of class \code{maxtest} or \code{mmaxtest} (if more than one
covariable was specified) containing the following components
is returned:
  \item{statistic }{the value of the test statistic.}
  \item{p.value }{the p-value for the test.}
  \item{smethod}{ the type of test applied.}
  \item{pmethod}{ the type of p-value approximation applied.}
  \item{estimate}{ the estimated cutpoint (of \code{x}) which separates
                   \code{y} best.} 
  \item{maxstats}{a list of \code{maxtest} objects, one for each
                  covariable.}
  \item{whichmin}{an integer specifying the element of \code{maxstats} with
                  smallest p-value.}
  \item{p.value}{the p-value of the global test.}
  \item{univp.values}{the p-values for each of the variables under test.}
  \item{cm}{the correlation matrix the p-value is based on.}
\code{\link{plot.maxtest}} and \code{\link{print.maxtest}} can be used for
plotting and printing. If \code{keepxy = TRUE}, there are elements \code{y}
and \code{x} giving the response and independent variable.
}
\references{ 

        Hothorn, T. and Lausen, B. (2003).
        On the Exact Distribution of Maximally Selected Rank Statistics. 
        \emph{Computational Statistics \& Data Analysis}, \bold{43}, 
        121--137.

	Lausen, B. and Schumacher, M. (1992).
        Maximally Selected Rank Statistics.
        \emph{Biometrics}, \bold{48}, 73--85

        Lausen, B., Sauerbrei, W. and Schumacher, M. (1994).
        Classification and Regression Trees (CART) used for the
        exploration of prognostic factors measured on different scales.
        in: P. Dirschedl and R. Ostermann (Eds), 
        \emph{Computational Statistics}, Heidelberg, Physica-Verlag,
        483--496

	Hothorn, T. (2001). On Exact Rank Tests in R.
	\emph{R News}, \bold{1}, 11--12

        Lausen, B., Hothorn, T., Bretz, F. and Schmacher, M. (2002).
        Assessment of Optimally Selected Prognostic Factors.
        \emph{submitted}. Preprint available from
        \url{http://www.mathpreprints.com/math/Preprint/blausen/20021007/1/}

}

\examples{

x <- sort(runif(20))
y <- c(rnorm(10), rnorm(10, 2))
mydata <- data.frame(cbind(x,y))

mod <- maxstat.test(y ~ x, data=mydata, smethod="Wilcoxon", pmethod="HL",
                    minprop=0.25, maxprop=0.75, alpha=0.05)
print(mod)
plot(mod)

# adjusted for more than one prognostic factor.

data(DLBCL)

mstat <- maxstat.test(Surv(time, cens) ~ IPI + MGE, data=DLBCL, 
                      smethod="LogRank", pmethod="exactGauss", 
                      abseps=0.01)
plot(mstat)

}
\keyword{htest}

\eof
\name{pLausen92}
\alias{pLausen92}
\alias{qLausen92}
\title{ Approximating Maximally Selected Statistics }
\description{

Approximates the probability that a maximally selected rank statistic is
greater or equal to \code{b}. 

}
\usage{
pLausen92(b, minprop=0.1, maxprop=0.9)
qLausen92(p, minprop=0.1, maxprop=0.9)
}
\arguments{
  \item{b}{ quantile. }
  \item{p}{ probability. }
  \item{minprop}{ at least \code{minprop}*100\% of the observations in the
first group. }
  \item{maxprop}{ not more than \code{minprop}*100\% of the observations in
the first group. }
}
\details{

Large sample approximation by Miller and Siegmund (1982) based on a Brownian
bridge, cf. Lausen and Schumacher (1992). 

}
\value{
The probability that, under the hypothesis of independence, a maximally
selected statistic greater equal \code{b} is observed.
}
\references{ 

	Miller, R. and Siegmund, D. (1982),
	Maximally Selected Chi Square Statistics.
	\emph{Biometrics}, \bold{38}, 1011--1016

	Lausen, B. and Schumacher, M. (1992),
	Maximally Selected Rank Statistics.
	\emph{Biometrics}, \bold{48}, 73--85

}

\examples{

# Compute quantiles. Should be equal to Table 2 in Lausen and Schumacher

data(LausenTab2)

a <- rev(c(0.01, 0.025, 0.05, 0.1))
prop <- rbind(c(0.25, 0.75), c(0.4, 0.6), c(0.1, 0.9), c(0.4, 0.9))
Quant <- matrix(rep(0, length(a)*nrow(prop)), nrow=length(a)) 

for (i in 1:length(a)) {                                            
  for (j in 1:nrow(prop)) {                            
    Quant[i,j] <- qLausen92(a[i], minprop=prop[j,1], maxprop=prop[j,2]) 
  }
}

Quant <- round(Quant, 3)
rownames(Quant) <- a
colnames(Quant) <- c("A2575", "A46", "A19", "A49")
Quant <- as.data.frame(Quant)
rownames(LausenTab2) <- a

Quant

LausenTab2

if(!all.equal(LausenTab2, Quant)) stop("error checking pLausen92")

}

\keyword{distribution}

\eof
\name{pLausen94}
\alias{pLausen94}
\alias{qLausen94}
\title{ Approximating Maximally Selected Statistics }
\description{

Approximates the probability that a maximally selected rank statistic is
greater or equal to \code{b}.

}
\usage{
pLausen94(b, N, minprop=0.1, maxprop=0.9, m=NULL)
qLausen94(p, N, minprop=0.1, maxprop=0.9, m=NULL)
}
\arguments{
  \item{b}{ quantile. }
  \item{p}{ probability. }
  \item{N}{ number of observations.}
\item{minprop}{ at least \code{minprop}*100\% of the observations in the
first group. }
  \item{maxprop}{ not more than \code{minprop}*100\% of the observations in
the first group. }
  \item{m}{a integer vector containing the sample sizes in the first groups
for each cutpoint considered. If \code{is.null(m)} a continuous predictor is
assumed. }
}
\details{

Approximation based on an improved Bonferroni inequality.

}
\value{
The probability that, under the hypothesis of independence, a maximally
selected statistic greater equal \code{b} is observed.
}
\references{ 

	Worsley, K.J. (1982),
	An Improved Bonferroni Inequality and Applications.
	\emph{Biometrika}, \bold{69}, 297--302

	Lausen, B. (1990),
	Maximal Selektierte Rangstatistiken. Dissertation. 
	Universit\"at Dortmund 

        Lausen, B., Sauerbrei, W. & Schumacher, M. (1994).
        Classification and Regression Trees (CART) used for the
        exploration of prognostic factors measured on different scales.
        in: P. Dirschedl & R. Ostermann (Eds),
        \emph{Computational Statistics}, Heidelberg, Physica-Verlag,
        483--496

}

\examples{

p <- pLausen94(2.5, 20, 0.25, 0.75)

# Lausen 94, page 489

if (round(p, 3) != 0.073) stop("error checking pLausen94")

# the same

p2 <- pLausen94(2.5, 200, 0.25, 0.75, m=seq(from=50, to=150, by=10))

stopifnot(all.equal(round(p,3), round(p2,3)))

}

\keyword{distribution}

\eof
\name{pexactgauss}
\alias{pexactgauss}
\alias{qexactgauss}
\title{ Computing Maximally Selected Gauss Statistics  }
\description{

Computes the exact probability that a maximally selected gauss statistic is
greater or equal to \code{b}.

}
\usage{
pexactgauss(b, x, minprop=0.1, maxprop=0.9, \dots)
qexactgauss(p, x, minprop=0.1, maxprop=0.9, \dots)
}
\arguments{
  \item{b}{ quantile. }
  \item{p}{ probability. } 
  \item{x}{ the prognostic factor(s) under test. }
  \item{minprop}{ at least \code{minprop}*100\% of the observations in the
                  first group. }
  \item{maxprop}{ not more than \code{minprop}*100\% of the observations in
                  the first group. }
  \item{\dots}{additional parameters to be passed to
\code{\link[mvtnorm]{pmvnorm}}.}
}
\details{

This is the exact distribution of a maximally selected Gauss statistic and
the asymptotic distribution for maximally selected rank statistics.
Normal probabilities are derived from the procedures by Genz/Bretz (see
\code{\link[mvtnorm]{pmvnorm}} for details).

}
\value{

The probability that, under the hypothesis of independence, a maximally
selected gauss statistic greater equal \code{b} is observed. 

}
\references{ 
	
        Genz, A. (1992). Numerical computation of multivariate normal probabilities.
        \emph{Journal of Computational and Graphical Statistics}, \bold{1}, 141--150

        Genz, A. (1993). Comparison of methods for the computation of multivariate
        normal probabilities. \emph{Computing Science and Statistics}, \bold{25},
        400--405

}
\examples{

x <- rnorm(20)

pexact <- pexactgauss(2.5, x, abseps=0.01)

}
\keyword{distribution}

\eof
\name{plot.maxtest}
\alias{plot.maxtest}
\alias{print.maxtest}
\alias{plot.mmaxtest}
\alias{print.mmaxtest}
\title{ Print and Plot Standardized Statistics }
\description{
Printing and ploting method of objects of class \code{maxtest}}
\usage{
\method{plot}{maxtest}(x, xlab=NULL, ylab=NULL, \dots)
\method{print}{maxtest}{x, \dots}
\method{plot}{mmaxtest}(x, xlab=NULL, ylab=NULL, nrow=2, \dots)
\method{print}{mmaxtest}{x, \dots}
}
\arguments{
  \item{x}{ an object of class \code{maxtest} or \code{mmaxtest}.}
  \item{xlab}{ label of x-axis. }
  \item{ylab}{ label of y-axis. }
  \item{nrow}{ number of rows for multiple plots at one page. }
  \item{\dots}{ additional arguments to \code{plot} or \code{print.htest}.}
}
\details{

The standardized statistics are plotted. If \code{alpha} was given in 
\code{\link{maxstat.test}} the appropriate significance bound is plotted as
a red line. \code{print.maxtest} is just a wrapper to \code{print.htest}.

}

\examples{

x <- sort(runif(20))
y <- rbinom(20, 1, 0.5)
mydata <- data.frame(c(x,y))

mod <- maxstat.test(y ~ x, data=mydata, smethod="Median", 
                    pmethod="HL", alpha=0.05)
print(mod)
plot(mod)

}
\keyword{htest}

\eof
\name{pmaxstat}
\alias{pmaxstat}
\alias{qmaxstat}
\title{ Approximating Maximally Selected Statistics }
\description{

Approximates the probability that a maximally selected rank
statistic is greater or equal to \code{b}.

}
\usage{
pmaxstat(b, scores, msample, quant=FALSE)
qmaxstat(p, scores, msample)
}
\arguments{
 \item{b}{ quantile. }
 \item{p}{propability. }
 \item{scores}{ integer valued scores assigned to the observations. }
 \item{msample}{ all possible splitpoints. }
 \item{quant}{ logical. Returns the results of SR instead of P-values. Only
               to be used in \code{qmaxstat}.}
}
\details{

Small sample approximation by Hothorn and Lausen (2003).

}
\value{

An upper limit for the probability that, under the hypothesis of 
independence, a maximally selected statistic greater equal \code{b} 
is observed. \code{qmaxstat} needs optimization.

}

\references{

	Hothorn, T. and Lausen, B. (2003).
        On the Exact Distribution of Maximally Selected Rank Statistics. 
        \emph{Computational Statistics \& Data Analysis}, \bold{43}, 
        121--137.
}

\examples{

pmaxstat(2.5, 1:20, 5:15)

}
\keyword{distribution}

\eof
\name{sphase}
\alias{sphase}
\non_function{}
\title{ S-phase fraction of tumor cells }
\usage{data(sphase)}
\description{
  S-phase fraction of tumor cells in breast cancer patients. 
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{SPF}{S-phase fraction}
    \item{RFS}{recurrence free survival}
    \item{cens}{censoring indicator (\code{1} event)}
  }
}
\details{

}
\source{
  J. Pfisterer, F. Kommoss, W. Sauerbrei, D. Menzel, M. Kiechle, E. Giese,
M. Hilgarth and A. Pfleiderer (1995). DNA flow cytometry in node positive
breast cancer: Prognostic value and correlation to morphological and
clinical factors. \emph{Analytical and Quantitative Cytology and Histology}
bold{7}(6), 406--412.
}
\references{

}
\examples{
data(sphase)
maxstat.test(Surv(RFS, cens) ~ SPF, data=sphase, smethod="LogRank",
pmethod="Lau94")
maxstat.test(Surv(RFS, cens) ~ SPF, data=sphase, smethod="LogRank",
pmethod="Lau94", iscores=TRUE)
maxstat.test(Surv(RFS, cens) ~ SPF, data=sphase, smethod="LogRank",
pmethod="HL")
maxstat.test(Surv(RFS, cens) ~ SPF, data=sphase, smethod="LogRank",
pmethod="condMC", B = 9999)
plot(maxstat.test(Surv(RFS, cens) ~ SPF, data=sphase, smethod="LogRank"))

}
\keyword{datasets}

\eof
\name{treepipit}
\alias{treepipit}
\docType{data}
\title{ Tree Pipit Data }
\description{
  Counts of tree pipits at 86 raster points in oak forests.
}
\usage{data(treepipit)}
\format{
  A data frame with 86 observations on the following 2 variables.
  \describe{
    \item{counts}{number of tree pipits counted.}
    \item{coverstorey}{canopy overstorey in percent.}
  }
}
\details{
  The influence of canopy overstorey on the number of bird 
  individuals is of special interest.
}
\source{
  Data collected and kindly provided by Joerg Mueller
  <mue@lwf.uni-muenchen.de>.
}
\references{
  Mueller J. and Hothorn T. (2003), On the Identification and Assessment of 
  Habitat Patterns with Impact in Breeding Bird Communities in Oak Forests.
  \emph{submitted manuscript}.
}
\examples{
data(treepipit)
mod <- maxstat.test(counts ~ coverstorey, data = treepipit, 
                    smethod = "Data", pmethod = "HL", minprop = 0.2,
                    maxprop = 0.8)
print(mod)
plot(mod)
}
\keyword{datasets}

\eof
